TBL2_HS_gen:
The target genes table for human miRNAs
Description
This function generates target gene tables for human miRNAs base upon simple seed match toward 3' UTR of target genes
Usage
TBL2_HS_gen(SP="hsa",destdir="./")
Arguments
SP
Three characters string which describe human. Default is "hsa".
destdir
Directory where "TBL2_HS" is saved. Default is "./".
Details
This function generates target gene tables for human miRNAs,
used in the MiRaGE server described in Yoshizawa et al (2011).
It saves data frame "TBL2" as the name of "TBL2_HS" in the destination directory.
References
Yoshizawa, M., Taguchi, Y-h., and Yasuda, J. (2011), Inference of Gene Regulation via miRNAs During ES Cell
Differentiation Using MiRaGE Method. Int J Mol Sci 12(12):9265-9276