Learn R Programming

MiRaGE (version 1.14.0)

getMiRaGEData: Data retrieval function for MiRaGE

Description

This function retrieves target gene tables of miRNAs, gene id conversion table and miRNA consevation tables

Usage

getMiRaGEData(location="local", species="MM", ID="refseq",method="mean",test="ks", conv="conserved",species_force=T,ID_force=T,conv_force=T)

Arguments

location
Specify from where tables are retrieved. If location="local", then tables are retrieved from experimental package, "miRNATarget". If location="web", tables are downloaded from MiRaGE Server web site, "http://www.granular.com/DATA/". Default is "local"
species
a string specifies target species. This should be either "MM" (mouse) or "HS" (human). Default is "MM".
ID
a string specifies gene ID. Default is "refseq".
method
a string specifies the treatment of samples. This should be one of "mean", "mixed", or "one_by_one". Default is "mean".
test
a string specifies statistical test for P-value computation. This should be one of "ks" (Kolmogorov-Smirnov test), "t" (t-test), or "wilcox" (Wilcoxon test). Default is "ks".
conv
a string specifies conservation of miRNA. This should be one of "conserved", "weak_conserve", and "all". Default is "conserved".
species_force
a boolean indicating whether target gene table is downloaded (TRUE) or not (FALSE). Default is TRUE.
ID_force
a boolean indicating whether gene ID conversion table is downloaded (TRUE) or not (FALSE). Default is TRUE.
conv_force
a boolean indicating whether miRNA conservation table is downloaded (TRUE) or not (FALSE). Default is TRUE.

Value

tb1
target gene tables of miRNAs. Rownames are miRNA named and colnames are gene ids
TBL2
Transposed matrix of tb1. This object is loaded after this function is called.
conv_id
Conservation table of miRNAs. It is retrieved only when "conv" is not equal to "all". This object is loaded after this function is called.
id_conv
Gene id conversion table between "refseq" ad specified gene id or probe id. This object is loaded after this function is called.

Details

This function retrieves various tables necessary for inference of target gene regulation by miRNAs, based upon the algorithm implemented in the MiRaGE server described in Yoshizawa et al (2011).

References

Yoshizawa, M., Taguchi, Y-h., and Yasuda, J. (2011), Inference of Gene Regulation via miRNAs During ES Cell Differentiation Using MiRaGE Method. Int J Mol Sci 12(12):9265-9276

Examples

Run this code
tb1 <- getMiRaGEData(species="HS")

Run the code above in your browser using DataLab