Get names for all the the slides

get_layout_names(pptx, error_call = current_env())

Arguments

pptx

Powerpoint file

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

character vector of layout names