id_conv_gen:
Conversion table between refseq id vs various gene id/probe id generation function
Description
This function generate id_conv, which describes conversion between refseq gene id vs various gene id/prob id, from the scratch
Usage
id_conv_gen(SP="MM",gene_id="all",destdir="./")
Arguments
SP
Species for which gene id conversion table is generated. "MM" for mouse, "HS" for human. Default is "MM"
gene_id
gene id for which conversion table toward refseq gene is generated. If "all" is specified, tables for all of available gene ids are generated. Default is "all".
destdir
Directory where data sets are saved. Default is "./".
Details
This function generates gene id conversion table, id_conv,
used in the MiRaGE server described in Yoshizawa et al (2011).
It saves data frames in the destination directory.
The name of data set including each id_conv is the form, "SP_refseq_to_gene_id_id", where SP is either MM or HS and gene_id is gene id defined in biomaRt attributes.
References
Yoshizawa, M., Taguchi, Y-h., and Yasuda, J. (2011), Inference of Gene Regulation via miRNAs During ES Cell
Differentiation Using MiRaGE Method. Int J Mol Sci 12(12):9265-9276