List layouts

list_layouts(pptx, error_call = current_env())

Arguments

pptx

A Powerpoint wrapped in a <pptx_container> object. see load_pptx()

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

A tibble with information about the layouts

Examples

list_layouts(load_pptx())
#> # A tibble: 7 × 5
#>   name        filename placeholders_count placeholders_summary placeholders_data
#>   <chr>       <chr>                 <int> <chr>                <list>           
#> 1 Title Slide slideLa…                  5 Title (1), Subtitle… <tibble [5 × 11]>
#> 2 Title and … slideLa…                  5 Title (1), Content … <tibble [5 × 11]>
#> 3 Section He… slideLa…                  5 Title (1), Text Pla… <tibble [5 × 11]>
#> 4 Two Content slideLa…                  6 Title (1), Content … <tibble [6 × 11]>
#> 5 Comparison  slideLa…                  8 Title (1), Text Pla… <tibble [8 × 11]>
#> 6 Title Only  slideLa…                  4 Title (1), Date Pla… <tibble [4 × 11]>
#> 7 Blank       slideLa…                  3 Date Placeholder (1… <tibble [3 × 11]>