List slides

list_slides(pptx, keep_all = FALSE, error_call = current_env())

Arguments

pptx

A Powerpoint wrapped in a <pptx_container> object. see load_pptx()

keep_all

if FALSE, only keep non missing placeholders

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

A tibble with information about the slides

Examples

list_slides(load_pptx())
#> # A tibble: 0 × 6
#> # ℹ 6 variables: slide_index <int>, slide_file <chr>, layout_name <chr>,
#> #   slide_ph <chr>, layout_ph <chr>, n_slide_ph <int>