extended properties metadata

metadata(data, uri = "r://package/mirage", error_call = current_env())

Arguments

data

Named character vector used as name= and value= for the custom:property nodes.

uri

uri, used in the p:ext node

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

a p:extLst tag

Examples

metadata(c(foo = "abc", bar = "def"))
#> <p:extLst>
#>   <p:ext uri="r://package/mirage">
#>     <custom:meta xmlns:custom="urn:schemas-microsoft-com:office:custom-properties">
#>       <custom:property name="foo" value="abc"/>
#>       <custom:property name="bar" value="def"/>
#>     </custom:meta>
#>   </p:ext>
#> </p:extLst>