Included standard template locations to put standard contents when constructing a slide.

These are all "templated_placeholder" objects, which allows the user to specify two potential placeholders, allowing passing a existing_placeholder object( ref_placeholder()), which tries to use an existing placeholder either in the slide or defined in the layout, and the fallback must be a new_placeholder object (new_placeholder()), which defines a placeholder into the slide without needing there to be a pre-defined placeholder in the slide layout.

templated_placeholder(preferred, fallback, error_call = current_env())

ph_title(replace = TRUE)

ph_subtitle(replace = TRUE)

ph_body(replace = TRUE)

ph_body_left(replace = TRUE)

ph_body_right(replace = TRUE)

ph_footer(replace = TRUE)

ph_footer_left(replace = TRUE)

ph_footer_right(replace = TRUE)

Arguments

preferred

placeholder object of class existing placeholder

fallback

placeholder object of class new_placeholder

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

replace

Identify whether to replace the existing placeholder if it exists on the slide. Defaults to TRUE.