Load/Save a PowerPoint file

load_pptx(path = NULL, name)

slide_errors(pptx)

save_pptx(pptx, path, error_call = current_env())

example_pptx()

Arguments

path

output path of file to be saved

name

name of the file

pptx

A Powerpoint wrapped in a <pptx_container> object. see load_pptx()

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

load_pptx() returns a new pptx_container object that wraps objects created by officer::read_pptx() with custom functionality for mirage.

Details

slide_errors() Extract a tibble of errors that occured when adding and updateing slides

Examples


pptx <- load_pptx(system.file("ref_files/standard_powerpoint.pptx", package = "mirage"))

pptx2<- load_pptx()