Read a single slide as xml

read_slide(pptx, index, error_call = current_env())

Arguments

pptx

A Powerpoint wrapped in a <pptx_container> object. see load_pptx()

index

slide index

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

Value

The slide, as read by xml2::read_xml