Remove placeholder from a slide

remove_slide_ph(
  pptx,
  ph_id,
  index,
  error_call = current_env(),
  verbose = getOption("mirage.verbose", default = FALSE)
)

Arguments

pptx

A Powerpoint wrapped in a <pptx_container> object. see load_pptx()

ph_id

placeholder id

index

index of slide

error_call

The execution environment of a currently running function, e.g. caller_env(). The function will be mentioned in error messages as the source of the error. See the call argument of abort() for more information.

verbose

inform about the removed placeholders