process_placeholder.RdInternal method for processing placeholder requests
process_placeholder(ph, pptx, index, ..., error_call = current_env())placeholder
A Powerpoint wrapped in a <pptx_container> object. see load_pptx()
Slide number
These dots are for future extensions and must be empty.
The execution environment of a currently
running function, e.g. caller_env(). The function will be
mentioned in error messages as the source of the error. See the
call argument of abort() for more information.