slide_transitions.RdSlide transitions define the transition to show when moving to the slide.
slide_transition_generic() allows the user to create and pass new types of
transitions. Otherwise, most standard transitions are already defined as
slide_transition_*() to allow the user to easily define a transtion and any
other assets the transition may need.
slide_transition_generic(
type,
transition_type_xml,
speed = c("med", "fast", "slow")
)
slide_transition_blinds(orientation = c("horz", "vert"), speed = "med")
slide_transition_checker(orientation = c("horz", "vert"), speed = "med")
slide_transition_circle(orientation = c("horz", "vert"), speed = "med")
slide_transition_comb(orientation = c("horz", "vert"), speed = "med")
slide_transition_cover(
direction = c("d", "l", "r", "u", "ld", "lu", "rd", "ru"),
speed = "med"
)
slide_transition_cut(black_screen = FALSE, speed = "med")
slide_transition_diamond(speed = "med")
slide_transition_dissolve(speed = "med")
slide_transition_fade(black_screen = FALSE, speed = "med")
slide_transition_newsflash(speed = "med")
slide_transition_plus(speed = "med")
slide_transition_pull(direction = c("ld", "lu", "rd", "ru"), speed = "med")
slide_transition_push(direction = c("d", "l", "r", "u"), speed = "med")
slide_transition_random(speed = "med")
slide_transition_randomBar(orientation = c("horz", "vert"), speed = "med")
slide_transition_split(
split = c("in", "out"),
orientation = c("horz", "vert"),
speed = "med"
)
slide_transition_pull(direction = c("ld", "lu", "rd", "ru"), speed = "med")
slide_transition_wedge(speed = "med")
slide_transition_wheel(spokes = 4L, speed = "med")
slide_transition_wipe(direction = c("d", "l", "r", "u"), speed = "med")
slide_transition_zoom(zoom = c("in", "out"), speed = "med")
slide_transition_null()string defining the slide transition type
string defining the OOXML of the transition type
speed of the slide transition - med, fast, or slow
specify "horz" or "vert", defining the orientation of a transition
specify the direction of transition, with possible values of d (down), l (left), r (right), u (up), ld (left down), lu (left up), rd (right down), ru (right up). Not every transition allows every direction. Check the available default values to see what values can be used for every transition
boolean identifying if the transition starts from a black screen and then transitions to new slide over black
specify the number of spokes in the wheel; values are integers.
specify the direction of zoom, "in" or "out"
pptx <- example_pptx()
## add a transition to a new slide
pptx <- pptx |>
add_slide(
layout = "Title and Content",
transition = slide_transition_checker()
)
## Update/add transition to n existing slide
pptx <- pptx |>
update_slide(
index = 1,
transition = slide_transition_dissolve()
)